% Quokka3 settingsfile for a 1cm x 1cm Si-perovskite tandem cell
%
% simple tandem unit cell
% based on a Fraunhofer ISE tandem cell design
% details see A. Fell et al., JPV (2022) submitted
%
% (c) 2022 Andreas Fell

Syntax = 'front and rear contact unit cell';

UnitCellType = 'standard';

Solver.SolutionType = 'light JV-curve';
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.BulkModelType = 'equivalent-circuit';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;

CellThickness = 250 um;

FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontFingerWidth = 50 um;
FrontFingerShadingFraction = 1;
FrontContactWidth = 50 um;
FrontContact.OhmicResistivity = 1e-3;
FrontContactPitch = 1.25 mm;

RearMetalShape = 'full';
RearContactShape = 'full';
RearContact.OhmicResistivity = 1e-3;

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Thermal.T = 298.15;

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file'; % Text is the top cell transmission to the bottom cell
Optical.TextZ.FrontText.Text.File = 'tandem_Text.csv';
Optical.TextZ.FrontText.Aext.Type = 'file'; % Aext is the parasitic absorption in the top cell materials during the first pass of light
Optical.TextZ.FrontText.Aext.File = 'tandem_Aext.csv';
Optical.TextZ.FrontText.Agen.Type = 'file'; % Agen is the active absorption in the top cell, i.e. the top cell EQE
Optical.TextZ.FrontText.Agen.File = 'tandem_APero.csv';
Optical.TextZ.FrontText.FacetAngle = 0;
Optical.TextZ.FrontZ.Type = 'parameterization'; % below parameterization is a best-fit to the ray tracing results
Optical.TextZ.FrontZ.Z0 = 20.51;
Optical.TextZ.FrontZ.Zinf = 1.201;
Optical.TextZ.FrontZ.Zp = 2.55;
Optical.ScaleGeneration = 1;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 3000;
Bulk.Electrical.Recombination.SRH(1).taup = 3000;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 150;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 10 fA/cm2;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 10 fA/cm2;
FullFrontSkin.Layer(1).Name = 'TopCell';
FullFrontSkin.Layer(1).Type = 'lumped-subcell';
FullFrontSkin.Layer(1).Subcell.JVType = 'two-diode';
FullFrontSkin.Layer(1).Subcell.J01 = 4e-21 A/cm2;
FullFrontSkin.Layer(1).Subcell.J02 = 5e-12 A/cm2;
FullFrontSkin.Layer(1).Subcell.Rseries = 2.5;
FullFrontSkin.Layer(1).Subcell.Rshunt = 1e10;

% rear side skin


FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 100;
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 20 fA/cm2;
